@@ -1,4 +1,4 @@
-from paramaterial import preparing, plotting, processing, modelling
+from paramaterial import preparing, plotting, processing, modelling, example
 from paramaterial.plug import DataItem, DataSet
 from paramaterial.modelling import ModelSet, ModelItem
 
